@@ -67,7 +67,9 @@ USERNAME = 'username'
 
 PIPELINE = setting('SOCIAL_AUTH_PIPELINE', (
                 'social_auth.backends.pipeline.social.social_auth_user',
-                'social_auth.backends.pipeline.associate.associate_by_email',
+                # Removed by default since it can be a dangerouse behavior that
+                # could lead to accounts take over.
+                #'social_auth.backends.pipeline.associate.associate_by_email',
                 'social_auth.backends.pipeline.user.get_username',
                 'social_auth.backends.pipeline.user.create_user',
                 'social_auth.backends.pipeline.social.associate_user',
@@ -277,7 +279,7 @@ class OpenIDBackend(SocialAuthBackend):
         # values
         values.update(self.values_from_response(response,
                                                 SREG_ATTR,
-                                                OLD_AX_ATTRS + \
+                                                OLD_AX_ATTRS +
                                                 AX_SCHEMA_ATTRS))
 
         fullname = values.get('fullname') or ''
@@ -294,7 +296,7 @@ class OpenIDBackend(SocialAuthBackend):
 
         values.update({'fullname': fullname, 'first_name': first_name,
                        'last_name': last_name,
-                       USERNAME: values.get(USERNAME) or \
+                       USERNAME: values.get(USERNAME) or
                                    (first_name.title() + last_name.title())})
         return values
 
@@ -688,7 +690,11 @@ class BaseOAuth2(BaseOAuth):
             args['response_type'] = self.RESPONSE_TYPE
 
         args.update(self.auth_extra_arguments())
-        return self.AUTHORIZATION_URL + '?' + urlencode(args)
+        if self.request.META.get('QUERY_STRING'):
+            query_string = '&' + self.request.META['QUERY_STRING']
+        else:
+            query_string = ''
+        return self.AUTHORIZATION_URL + '?' + urlencode(args) + query_string
 
     def validate_state(self):
         """Validate state value. Raises exception on error, returns state
