@@ -11,11 +11,11 @@ setting, it must be a list of values to request.
 By default account id and token expiration time are stored in extra_data
 field, check OAuthBackend class for details on how to extend it.
 """
-from urllib import urlencode, urlopen
+from urllib import urlencode
 
 from django.utils import simplejson
 
-from social_auth.utils import setting
+from social_auth.utils import setting, dsa_urlopen
 from social_auth.backends import BaseOAuth2, OAuthBackend, USERNAME
 
 
@@ -51,11 +51,8 @@ class GithubAuth(BaseOAuth2):
     SETTINGS_KEY_NAME = 'GITHUB_APP_ID'
     SETTINGS_SECRET_NAME = 'GITHUB_API_SECRET'
     SCOPE_SEPARATOR = ','
-
-    def get_scope(self):
-        """Return list with needed access scope"""
-        # Look at http://developer.github.com/v3/oauth/
-        return setting('GITHUB_EXTENDED_PERMISSIONS', [])
+    # Look at http://developer.github.com/v3/oauth/
+    SCOPE_VAR_NAME = 'GITHUB_EXTENDED_PERMISSIONS'
 
     def user_data(self, access_token, *args, **kwargs):
         """Loads user data from service"""
@@ -63,7 +60,7 @@ class GithubAuth(BaseOAuth2):
             'access_token': access_token
         })
         try:
-            return simplejson.load(urlopen(url))
+            return simplejson.load(dsa_urlopen(url))
         except ValueError:
             return None
 
