@@ -8,6 +8,7 @@ from xml.parsers.expat import ExpatError
 
 from social_auth.utils import setting
 from social_auth.backends import ConsumerBasedOAuth, OAuthBackend, USERNAME
+from social_auth.backends.exceptions import AuthCanceled, AuthUnknownError
 
 
 LINKEDIN_SERVER = 'linkedin.com'
@@ -33,11 +34,12 @@ class LinkedinBackend(OAuthBackend):
     def get_user_details(self, response):
         """Return user details from Linkedin account"""
         first_name, last_name = response['first-name'], response['last-name']
+        email = response.get('email-address', '')
         return {USERNAME: first_name + last_name,
                 'fullname': first_name + ' ' + last_name,
                 'first_name': first_name,
                 'last_name': last_name,
-                'email': ''}
+                'email': email}
 
 
 class LinkedinAuth(ConsumerBasedOAuth):
@@ -62,6 +64,17 @@ class LinkedinAuth(ConsumerBasedOAuth):
         except (ExpatError, KeyError, IndexError):
             return None
 
+    def auth_complete(self, *args, **kwargs):
+        """Complete auth process. Check LinkedIn error response."""
+        oauth_problem = self.request.GET.get('oauth_problem')
+        if oauth_problem:
+            if oauth_problem == 'user_refused':
+                raise AuthCanceled(self, '')
+            else:
+                raise AuthUnknownError(self, 'LinkedIn error was %s' %
+                                                    oauth_problem)
+        return super(LinkedinAuth, self).auth_complete(*args, **kwargs)
+
 
 def to_dict(xml):
     """Convert XML structure to dict recursively, repeated keys entries
